==> kubernetes-model-admissionregistration-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends BaseFluent<A>{
  public ValidatingWebhookConfigurationFluent() {
  }
  public ValidatingWebhookConfigurationFluent(ValidatingWebhookConfiguration instance) {
    instance = (instance != null ? instance : new ValidatingWebhookConfiguration());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withWebhooks(instance.getWebhooks());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withWebhooks(instance.getWebhooks());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ArrayList<ValidatingWebhookBuilder> webhooks = new ArrayList<ValidatingWebhookBuilder>();
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public boolean hasKind() {
    return this.kind != null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  public MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MetadataNested(item);
  }
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ObjectMetaBuilder().build()));
  }
  public MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  public A addToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").add(index, builder); webhooks.add(index, builder);}
    return (A)this;
  }
  public A setToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").set(index, builder); webhooks.set(index, builder);}
    return (A)this;
  }
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A addAllToWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) return (A)this;
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder); this.webhooks.remove(builder);} return (A)this;
  }
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) return (A)this;
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder); this.webhooks.remove(builder);} return (A)this;
  }
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate) {
    if (webhooks == null) return (A) this;
    final Iterator<ValidatingWebhookBuilder> each = webhooks.iterator();
    final List visitables = _visitables.get("webhooks");
    while (each.hasNext()) {
      ValidatingWebhookBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<ValidatingWebhook> buildWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  public ValidatingWebhook buildWebhook(int index) {
    return this.webhooks.get(index).build();
  }
  public ValidatingWebhook buildFirstWebhook() {
    return this.webhooks.get(0).build();
  }
  public ValidatingWebhook buildLastWebhook() {
    return this.webhooks.get(webhooks.size() - 1).build();
  }
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withWebhooks(List<ValidatingWebhook> webhooks) {
    if (this.webhooks != null) { _visitables.get("webhooks").clear();}
    if (webhooks != null) {this.webhooks = new ArrayList(); for (ValidatingWebhook item : webhooks){this.addToWebhooks(item);}} else { this.webhooks = null;} return (A) this;
  }
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks) {
    if (this.webhooks != null) {this.webhooks.clear(); _visitables.remove("webhooks"); }
    if (webhooks != null) {for (ValidatingWebhook item :webhooks){ this.addToWebhooks(item);}} return (A) this;
  }
  public boolean hasWebhooks() {
    return webhooks != null && !webhooks.isEmpty();
  }
  public WebhooksNested<A> addNewWebhook() {
    return new WebhooksNested(-1, null);
  }
  public WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item) {
    return new WebhooksNested(-1, item);
  }
  public WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item) {
    return new WebhooksNested(index, item);
  }
  public WebhooksNested<A> editWebhook(int index) {
    if (webhooks.size() <= index) throw new RuntimeException("Can't edit webhooks. Index exceeds size.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public WebhooksNested<A> editFirstWebhook() {
    if (webhooks.size() == 0) throw new RuntimeException("Can't edit first webhooks. The list is empty.");
    return setNewWebhookLike(0, buildWebhook(0));
  }
  public WebhooksNested<A> editLastWebhook() {
    int index = webhooks.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last webhooks. The list is empty.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    int index = -1;
    for (int i=0;i<webhooks.size();i++) { 
    if (predicate.test(webhooks.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching webhooks. No match found.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingWebhookConfigurationFluent that = (ValidatingWebhookConfigurationFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(webhooks, that.webhooks)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  webhooks,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (webhooks != null && !webhooks.isEmpty()) { sb.append("webhooks:"); sb.append(webhooks + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluent.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class WebhooksNested<N> extends ValidatingWebhookFluent<WebhooksNested<N>> implements Nested<N>{
    WebhooksNested(int index,ValidatingWebhook item) {
      this.index = index;
      this.builder = new ValidatingWebhookBuilder(this, item);
    }
    ValidatingWebhookBuilder builder;
    int index;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluent.this.setToWebhooks(index,builder.build());
    }
    public N endWebhook() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends BaseFluent<A>{
  public ValidatingWebhookConfigurationFluent() {
  }
  
  public ValidatingWebhookConfigurationFluent(ValidatingWebhookConfiguration instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ArrayList<ValidatingWebhookBuilder> webhooks = new ArrayList<ValidatingWebhookBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ValidatingWebhookConfiguration instance) {
    instance = (instance != null ? instance : new ValidatingWebhookConfiguration());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withWebhooks(instance.getWebhooks());
        this.withApiVersion(instance.getApiVersion());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withWebhooks(instance.getWebhooks());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public A addToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").add(index, builder); webhooks.add(index, builder);}
    return (A)this;
  }
  
  public A setToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").set(index, builder); webhooks.set(index, builder);}
    return (A)this;
  }
  
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  
  public A addAllToWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) return (A)this;
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder); this.webhooks.remove(builder);} return (A)this;
  }
  
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) return (A)this;
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder); this.webhooks.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate) {
    if (webhooks == null) return (A) this;
    final Iterator<ValidatingWebhookBuilder> each = webhooks.iterator();
    final List visitables = _visitables.get("webhooks");
    while (each.hasNext()) {
      ValidatingWebhookBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ValidatingWebhook> buildWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  
  public ValidatingWebhook buildWebhook(int index) {
    return this.webhooks.get(index).build();
  }
  
  public ValidatingWebhook buildFirstWebhook() {
    return this.webhooks.get(0).build();
  }
  
  public ValidatingWebhook buildLastWebhook() {
    return this.webhooks.get(webhooks.size() - 1).build();
  }
  
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withWebhooks(List<ValidatingWebhook> webhooks) {
    if (this.webhooks != null) { _visitables.get("webhooks").clear();}
    if (webhooks != null) {this.webhooks = new ArrayList(); for (ValidatingWebhook item : webhooks){this.addToWebhooks(item);}} else { this.webhooks = null;} return (A) this;
  }
  
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks) {
    if (this.webhooks != null) {this.webhooks.clear(); _visitables.remove("webhooks"); }
    if (webhooks != null) {for (ValidatingWebhook item :webhooks){ this.addToWebhooks(item);}} return (A) this;
  }
  
  public boolean hasWebhooks() {
    return webhooks != null && !webhooks.isEmpty();
  }
  
  public WebhooksNested<A> addNewWebhook() {
    return new WebhooksNested(-1, null);
  }
  
  public WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item) {
    return new WebhooksNested(-1, item);
  }
  
  public WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item) {
    return new WebhooksNested(index, item);
  }
  
  public WebhooksNested<A> editWebhook(int index) {
    if (webhooks.size() <= index) throw new RuntimeException("Can't edit webhooks. Index exceeds size.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  
  public WebhooksNested<A> editFirstWebhook() {
    if (webhooks.size() == 0) throw new RuntimeException("Can't edit first webhooks. The list is empty.");
    return setNewWebhookLike(0, buildWebhook(0));
  }
  
  public WebhooksNested<A> editLastWebhook() {
    int index = webhooks.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last webhooks. The list is empty.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  
  public WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    int index = -1;
    for (int i=0;i<webhooks.size();i++) { 
    if (predicate.test(webhooks.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching webhooks. No match found.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingWebhookConfigurationFluent that = (ValidatingWebhookConfigurationFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    if (!java.util.Objects.equals(webhooks, that.webhooks)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  webhooks,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (webhooks != null && !webhooks.isEmpty()) { sb.append("webhooks:"); sb.append(webhooks + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    ObjectMetaBuilder builder;
    
    public N and() {
      return (N) ValidatingWebhookConfigurationFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }
  public class WebhooksNested<N> extends ValidatingWebhookFluent<WebhooksNested<N>> implements Nested<N>{
    WebhooksNested(int index,ValidatingWebhook item) {
      this.index = index;
      this.builder = new ValidatingWebhookBuilder(this, item);
    }
    ValidatingWebhookBuilder builder;
    int index;
    
    public N and() {
      return (N) ValidatingWebhookConfigurationFluent.this.setToWebhooks(index,builder.build());
    }
    
    public N endWebhook() {
      return and();
    }
    
  
  }

}
